==> kubernetes-model-apiextensions-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionSpecFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface CustomResourceDefinitionSpecFluent<A extends CustomResourceDefinitionSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildConversion instead.
 * @return The buildable object.
 */
@Deprecated public CustomResourceConversion getConversion();
    public CustomResourceConversion buildConversion();
    public A withConversion(CustomResourceConversion conversion);
    public Boolean hasConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversionLike(CustomResourceConversion item);
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> editConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversionLike(CustomResourceConversion item);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(String arg1);
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNames instead.
 * @return The buildable object.
 */
@Deprecated public CustomResourceDefinitionNames getNames();
    public CustomResourceDefinitionNames buildNames();
    public A withNames(CustomResourceDefinitionNames names);
    public Boolean hasNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNamesLike(CustomResourceDefinitionNames item);
    public CustomResourceDefinitionSpecFluent.NamesNested<A> editNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNamesLike(CustomResourceDefinitionNames item);
    public Boolean isPreserveUnknownFields();
    public A withPreserveUnknownFields(Boolean preserveUnknownFields);
    public Boolean hasPreserveUnknownFields();
    public A withNewPreserveUnknownFields(String arg1);
    public A withNewPreserveUnknownFields(boolean arg1);
    public String getScope();
    public A withScope(String scope);
    public Boolean hasScope();
    public A withNewScope(String arg1);
    public A withNewScope(StringBuilder arg1);
    public A withNewScope(StringBuffer arg1);
    public A addToVersions(int index,CustomResourceDefinitionVersion item);
    public A setToVersions(int index,CustomResourceDefinitionVersion item);
    public A addToVersions(CustomResourceDefinitionVersion... items);
    public A addAllToVersions(Collection<CustomResourceDefinitionVersion> items);
    public A removeFromVersions(CustomResourceDefinitionVersion... items);
    public A removeAllFromVersions(Collection<CustomResourceDefinitionVersion> items);
    public A removeMatchingFromVersions(io.fabric8.kubernetes.api.builder.Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildVersions instead.
 * @return The buildable object.
 */
@Deprecated public List<CustomResourceDefinitionVersion> getVersions();
    public List<CustomResourceDefinitionVersion> buildVersions();
    public CustomResourceDefinitionVersion buildVersion(int index);
    public CustomResourceDefinitionVersion buildFirstVersion();
    public CustomResourceDefinitionVersion buildLastVersion();
    public CustomResourceDefinitionVersion buildMatchingVersion(io.fabric8.kubernetes.api.builder.Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    public Boolean hasMatchingVersion(io.fabric8.kubernetes.api.builder.Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    public A withVersions(List<CustomResourceDefinitionVersion> versions);
    public A withVersions(CustomResourceDefinitionVersion... versions);
    public Boolean hasVersions();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersion();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersionLike(CustomResourceDefinitionVersion item);
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> setNewVersionLike(int index,CustomResourceDefinitionVersion item);
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editVersion(int index);
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editFirstVersion();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editLastVersion();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editMatchingVersion(io.fabric8.kubernetes.api.builder.Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    public interface ConversionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CustomResourceConversionFluent<CustomResourceDefinitionSpecFluent.ConversionNested<N>> {

        public N and();
        public N endConversion();    }


    public interface NamesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CustomResourceDefinitionNamesFluent<CustomResourceDefinitionSpecFluent.NamesNested<N>> {

        public N and();
        public N endNames();    }


    public interface VersionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CustomResourceDefinitionVersionFluent<CustomResourceDefinitionSpecFluent.VersionsNested<N>> {

        public N and();
        public N endVersion();    }


}

==> kubernetes-model-apiextensions-5.2.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionSpecFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface CustomResourceDefinitionSpecFluent<A extends CustomResourceDefinitionSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildConversion instead.
 * @return The buildable object.
 */
@Deprecated public CustomResourceConversion getConversion();
    public CustomResourceConversion buildConversion();
    public A withConversion(CustomResourceConversion conversion);
    public Boolean hasConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversionLike(CustomResourceConversion item);
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> editConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversion();
    public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversionLike(CustomResourceConversion item);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(String arg1);
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNames instead.
 * @return The buildable object.
 */
@Deprecated public CustomResourceDefinitionNames getNames();
    public CustomResourceDefinitionNames buildNames();
    public A withNames(CustomResourceDefinitionNames names);
    public Boolean hasNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNamesLike(CustomResourceDefinitionNames item);
    public CustomResourceDefinitionSpecFluent.NamesNested<A> editNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNames();
    public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNamesLike(CustomResourceDefinitionNames item);
    public Boolean isPreserveUnknownFields();
    public A withPreserveUnknownFields(Boolean preserveUnknownFields);
    public Boolean hasPreserveUnknownFields();
    public A withNewPreserveUnknownFields(String arg1);
    public A withNewPreserveUnknownFields(boolean arg1);
    public String getScope();
    public A withScope(String scope);
    public Boolean hasScope();
    public A withNewScope(String arg1);
    public A withNewScope(StringBuilder arg1);
    public A withNewScope(StringBuffer arg1);
    public A addToVersions(int index,CustomResourceDefinitionVersion item);
    public A setToVersions(int index,CustomResourceDefinitionVersion item);
    public A addToVersions(CustomResourceDefinitionVersion... items);
    public A addAllToVersions(Collection<CustomResourceDefinitionVersion> items);
    public A removeFromVersions(CustomResourceDefinitionVersion... items);
    public A removeAllFromVersions(Collection<CustomResourceDefinitionVersion> items);
    public A removeMatchingFromVersions(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildVersions instead.
 * @return The buildable object.
 */
@Deprecated public List<CustomResourceDefinitionVersion> getVersions();
    public List<CustomResourceDefinitionVersion> buildVersions();
    public CustomResourceDefinitionVersion buildVersion(int index);
    public CustomResourceDefinitionVersion buildFirstVersion();
    public CustomResourceDefinitionVersion buildLastVersion();
    public CustomResourceDefinitionVersion buildMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    public Boolean hasMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    public A withVersions(List<CustomResourceDefinitionVersion> versions);
    public A withVersions(CustomResourceDefinitionVersion... versions);
    public Boolean hasVersions();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersion();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersionLike(CustomResourceDefinitionVersion item);
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> setNewVersionLike(int index,CustomResourceDefinitionVersion item);
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editVersion(int index);
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editFirstVersion();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editLastVersion();
    public CustomResourceDefinitionSpecFluent.VersionsNested<A> editMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
    public interface ConversionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CustomResourceConversionFluent<CustomResourceDefinitionSpecFluent.ConversionNested<N>> {

            public N and();
            public N endConversion();    }


    public interface NamesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CustomResourceDefinitionNamesFluent<CustomResourceDefinitionSpecFluent.NamesNested<N>> {

            public N and();
            public N endNames();    }


    public interface VersionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CustomResourceDefinitionVersionFluent<CustomResourceDefinitionSpecFluent.VersionsNested<N>> {

            public N and();
            public N endVersion();    }


}
